@@ -5,16 +5,10 @@
   </tr>
 </table>
 
-<hr size="1" color="#404040" width="80%" />
-
 <?php if(!$man) { ?>
-  <p align="center">by Jan Engelhardt</p>
   <p><a href="http://sourceforge.net/" target="_blank"><img
   src="http://sourceforge.net/sflogo.php?group_id=120202&amp;type=6"
   alt="SourceForge" border="0" /></a></p>
-<?php } else { ?>
-  <table width="100%"><tr><td align="center">by Jan
-  Engelhardt</td></tr></table>
 <?php } ?>
 
 </body>
