@@ -1,25 +1,25 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/rdsh.c - Shared functions for RPLD/INFOD/RPLCTL
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
-  -- License restrictions apply (GPL v2)
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
+  -- License restrictions apply (LGPL v2.1)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  under the terms of the GNU Lesser General Public License as published
+  by the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program kit; if not, write to:
   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA  02110-1301  USA
 
-  -- For details, see the file named "LICENSE.GPL2"
+  -- For details, see the file named "LICENSE.LGPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -60,7 +60,7 @@ static pthread_mutex_t k_version_lock = PTHREAD_MUTEX_INITIALIZER;
 
 //-----------------------------------------------------------------------------
 struct tty *get_tty(uint32_t dev, int create) {
-    struct HXbtree_node *ts;
+    const struct HXbtree_node *ts;
     struct tty *ret = NULL, *tty;
 
     if((ret = HXbtree_get(Ttys, (void *)dev)) != NULL)
@@ -77,7 +77,7 @@ struct tty *get_tty(uint32_t dev, int create) {
     tty->sdev     = NULL;
     tty->full_dev = NULL;
 
-    if((ts = HXbtree_add(Ttys, (void *)dev, tty)) == NULL) {
+    if((ts = HXbtree_add(Ttys, (const void *)dev, tty)) == NULL) {
         free(tty);
         notify(LOG_ERR, _("%s: Memory allocation failure\n"), __FUNCTION__);
         return NULL;
@@ -101,7 +101,7 @@ void log_close(struct tty *tty) {
         get_tty(). If it is IFP_DEACTIVSES, it will change to IFP_ACTIVATED,
         as per definition. So we only need the data structure if
         IFP_DEACTIVATED is on. */
-        HXbtree_del(Ttys, (void *)tty->dev);
+        HXbtree_del(Ttys, (const void *)tty->dev);
         free(tty);
     }
     return;
@@ -129,13 +129,13 @@ void notify(int lv, const char *fmt, ...) {
 ssize_t send_wait(int fd, const void *buf, size_t count, int flags) {
     size_t rem = count;
     while(rem > 0) {
-        ssize_t eax = send(fd, buf, rem, flags);
-        if(eax < 0)
+        ssize_t ret = send(fd, buf, rem, flags);
+        if(ret < 0)
             return -errno;
-        if(eax == rem)
+        if(ret == rem)
             break;
-        buf += eax;
-        rem -= eax;
+        buf += ret;
+        rem -= ret;
         usleep(10000);
     }
     return count;
