@@ -171,6 +171,10 @@ static void mainloop(int fd) {
         if((ret = read(fd, &packet, sizeof(struct rpldev_packet))) <
          (ssize_t)sizeof(struct rpldev_packet)) {
             struct stat sb;
+#if defined(__OpenBSD__) || defined(__NetBSD__)
+            if(errno == EINTR)
+                continue;
+#endif
             fstat(fd, &sb);
             if(!S_ISREG(sb.st_mode))
                 fprintf(stderr, _("\n" "Short read: %ld bytes only. "
@@ -542,7 +546,7 @@ static int init_device(const char *in_devs) {
         if(errno != ENOENT) {
             if(errno == EACCES)
                 fprintf(stderr, _("The device should be owned by the user "
-                 "running rpld (uid %ld) and have mode 0400.\n"), GOpt.user_id);
+                 "running rpld (UID %ld) and have mode 0400.\n"), GOpt.user_id);
             fprintf(stderr, _("static_find(): Could not open %s even"
              " though it exists: %s (trying next device)\n"),
              devp, strerror(errno));
